@@ -1,15 +1,22 @@
 #' Provide a succinct summary of an object
 #'
 #' `tbl_sum()` gives a brief textual description of a table-like object,
-#' which should include the dimensions, the data source, and possible grouping
-#' (for `dplyr`).  The default implementation forwards to [pillar::obj_sum()].
+#' which should include the dimensions and the data source in the first element,
+#' and additional information in the other elements (such as grouping for \pkg{dplyr}).
+#' The default implementation forwards to [pillar::obj_sum()].
+#'
+#' @return A named character vector, describing the dimensions in the first element
+#'   and the data source in the name of the first element.
+#'
 #' @seealso [pillar::type_sum()], [pillar::is_vector_s3()]
 #' @param x Object to summarise
 #' @export
 tbl_sum <- function(x) UseMethod("tbl_sum", x)
 
 #' @export
-tbl_sum.default <- function(x) obj_sum(x)
+tbl_sum.default <- function(x) {
+  c("Description" = obj_sum(x))
+}
 
 #' @export
 tbl_sum.tbl <- function(x) {
@@ -19,7 +26,6 @@ tbl_sum.tbl <- function(x) {
 dim_desc <- function(x) {
   dim <- dim(x) %||% length(x)
   format_dim <- map_chr(dim, big_mark)
-  format_dim[is.na(dim)] <- "??"
   paste0(format_dim, collapse = spaces_around(mult_sign()))
 }
 
