@@ -1,9 +1,42 @@
-## ---- echo = FALSE, message = FALSE--------------------------------------
+## ---- echo = FALSE, message = FALSE, error = TRUE------------------------
 knitr::opts_chunk$set(collapse = TRUE, comment = "#>")
-options(tibble.print_min = 4L, tibble.print_max = 4L)
 library(tibble)
 set.seed(1014)
 
+options(crayon.enabled = TRUE)
+options(pillar.bold = TRUE)
+
+knitr::opts_chunk$set(collapse = TRUE, comment = pillar::style_subtle("#>"))
+
+colourise_chunk <- function(type) {
+  function(x, options) {
+    # lines <- strsplit(x, "\\n")[[1]]
+    lines <- x
+    if (type != "output") {
+      lines <- crayon::red(lines)
+    }
+    paste0(
+      '<div class="sourceCode"><pre class="sourceCode"><code class="sourceCode">',
+      paste0(
+        sgr_to_html(htmltools::htmlEscape(lines)),
+        collapse = "\n"
+      ),
+      "</code></pre></div>"
+    )
+  }
+}
+
+knitr::knit_hooks$set(
+  output = colourise_chunk("output"),
+  message = colourise_chunk("message"),
+  warning = colourise_chunk("warning"),
+  error = colourise_chunk("error")
+)
+
+# Fallback if fansi is missing
+sgr_to_html <- identity
+sgr_to_html <- fansi::sgr_to_html
+
 ## ------------------------------------------------------------------------
 tibble(x = letters)
 
@@ -17,19 +50,23 @@ names(tibble(`crazy name` = 1))
 ## ------------------------------------------------------------------------
 tibble(x = 1:5, y = x ^ 2)
 
-## ------------------------------------------------------------------------
-if (requireNamespace("microbenchmark", quiet = TRUE)) {
-  l <- replicate(26, sample(100), simplify = FALSE)
-  names(l) <- letters
+## ----error = TRUE, eval = FALSE------------------------------------------
+#  l <- replicate(26, sample(100), simplify = FALSE)
+#  names(l) <- letters
+#  
+#  timing <- bench::mark(
+#    as_tibble(l),
+#    as.data.frame(l),
+#    check = FALSE
+#  )
+#  
+#  timing
 
-  microbenchmark::microbenchmark(
-    as_tibble(l),
-    as.data.frame(l)
-  )
-}
+## ----echo = FALSE--------------------------------------------------------
+readRDS("timing.rds")
 
 ## ------------------------------------------------------------------------
-tibble(x = 1:1000)
+tibble(x = -5:1000)
 
 ## ------------------------------------------------------------------------
 df1 <- data.frame(x = 1:3, y = 3:1)
